summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author Aaron Giles <aaron@aarongiles.com>2009-03-05 08:22:45 +0000
committer Aaron Giles <aaron@aarongiles.com>2009-03-05 08:22:45 +0000
commit328aa85a24abf4dfd995529cf3a5e2ca8d68e5e2 (patch)
tree973976bb1ba4c72f7f4a1f3384d6fbda33ac7237
parentc0b9bcf36c712c46480080db8b1014d01793cc5b (diff)
From: R. Reucher [rene.reucher@batcom-it.net]
Sent: Friday, February 27, 2009 10:17 AM To: submit@mamedev.org Cc: qmc2-devel@lists.sourceforge.net Subject: Proposed patch for src/emu/audit.c Dear MAME developers, I've created the attached diff to src/emu/audit.c (0.129u5) to allow for reporting a ROM state of "correct" when a game/machine doesn't require any ROM files at all (currently it will be reported as "not found", which is wrong IMHO). I know that this isn't really relevant for MAME, but it is for MESS -- so I hope you'll accept the patch. Thanks, Rene -- Rene Reucher rene.reucher@batcom-it.net http://www.batcom-it.net/ It is only people of small moral stature who have to stand on their dignity.
-rw-r--r--src/emu/audit.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/emu/audit.c b/src/emu/audit.c
index 856857013c9..211cc6d5941 100644
--- a/src/emu/audit.c
+++ b/src/emu/audit.c
@@ -230,9 +230,11 @@ int audit_summary(const game_driver *gamedrv, int count, const audit_record *rec
int notfound = 0;
int recnum;
- /* no count or records means not found */
- if (count == 0 || records == NULL)
+ /* no count AND no records means not found, no count only means no ROMs required (= correct) */
+ if (count == 0 && records == NULL)
return NOTFOUND;
+ else if (count == 0)
+ return CORRECT;
/* loop over records */
for (recnum = 0; recnum < count; recnum++)